@@ -25,3 +25,12 @@ class UninitializedRepositoryError(Exception):
 
 class PemissionDeniedError(Exception):
     pass
+
+class TaskNotExistsError(Exception):
+    """Task directory does not exists."""
+
+class TaskAlreadyExistsError(Exception):
+    """Task directory already exists."""
+
+class GistoreLockError(Exception):
+    """Lock failed."""
