@@ -15,12 +15,18 @@
 #
 
 import os
+import pwd
 from gistore.errors import *
 
 class AbstractSCM(object):
 
-    def __init__(self, root=""):
+
+    def __init__(self, root="", work_tree=".", backup_history=0, backup_copies=0):
         self.set_root(root)
+        self.backup_history = backup_history
+        self.backup_copies  = backup_copies
+        self.username = pwd.getpwuid(os.getuid())[0] or "gistore"
+        self.WORK_TREE = work_tree
 
     def set_root(self, root=""):
         if not root:
@@ -32,13 +38,13 @@ class AbstractSCM(object):
             raise UninitializedRepositoryError
 
     def is_repos(self):
-        raise NoImplementError
+        raise NoImplementError("not implement is_repos")
 
     def init(self):
-        raise NoImplementError
+        raise NoImplementError("not implement init")
 
     def commit(self):
-        raise NoImplementError
+        raise NoImplementError("not implement commit")
 
     def post_check(self):
         return
